@@ -1,6 +1,8 @@
 from __future__ import annotations
 from typing import List, Union
+from corkus.objects.member import Member
 
+from corkus.utils.utils import Utils
 from .base import CorkusBase
 from .server import Server
 from .partial_online_player import PartialOnlinePlayer
@@ -24,27 +26,18 @@ class OnlinePlayers(CorkusBase):
         """List all online players that are playing on regular servers."""
         return [p for s in self.servers if s.regular for p in s.players]
 
-    def get_player_server(self, player: Union[str, Player, PartialPlayer, PartialOnlinePlayer]) -> Union[Server, None]:
+    def get_player_server(self, player: Union[str, Player, PartialPlayer, PartialOnlinePlayer, Member]) -> Union[Server, None]:
         """Get the server that player is currently playing on. Returns ``None`` if player is offline.
 
         :param player: Player username or player object to check for.
         """
-        if isinstance(player, str):
-            username = player
-        elif isinstance(player, (Player, PartialOnlinePlayer)):
-            username = player.username
-        elif isinstance(player, PartialPlayer):
-            username = player.username
-            if username is None:
-                raise ValueError("expected PartialPlayer with username")
-        else:
-            raise TypeError(f"expected str, Player, PartialPlayer or PartialOnlinePlayer, received {type(player)}")
+        username = Utils.player_to_username(player)
         for p in self.players:
             if p.username == username:
                 return p.server
         return None
 
-    def is_player_online(self, player: Union[str, Player, PartialPlayer, PartialOnlinePlayer]) -> bool:
+    def is_player_online(self, player: Union[str, Player, PartialPlayer, PartialOnlinePlayer, Member]) -> bool:
         """Check if player is online.
 
         :param player: Player username or player object to check for.
